@@ -47,7 +47,8 @@ class TortoiseMixin:
                 column_name = f"{column_name}_id"
 
             is_m2m = field_type == "ManyToManyFieldInstance"
-            is_upload = False
+            w_type, _ = self.formfield_overrides.get(field_name, (None, None))
+            is_upload = w_type == WidgetType.Upload
             if with_m2m is not None and not with_m2m and is_m2m:
                 continue
             if with_m2m is not None and with_m2m and not is_m2m:
@@ -134,6 +135,8 @@ class TortoiseMixin:
                         form_widget_type = WidgetType.Select
                         filter_widget_type = WidgetType.Select
                         filter_widget_props["mode"] = "multiple"
+                case "JSONField":
+                    form_widget_type = WidgetType.JsonTextArea
 
             # relations
             if field_type in ("ForeignKeyFieldInstance", "OneToOneFieldInstance", "ManyToManyFieldInstance"):
@@ -197,7 +200,7 @@ class TortoiseMixin:
                                 filter_widget_type = WidgetType.AsyncSelect
                                 filter_widget_props["mode"] = "multiple"
 
-            form_widget_type, form_widget_props = self.form_fields_widgets.get(
+            form_widget_type, form_widget_props = self.formfield_overrides.get(
                 field_name, (form_widget_type, form_widget_props)
             )
             fields.append(
