@@ -9,9 +9,14 @@ class WidgetType(str, Enum):
 
     Input = "Input"
     InputNumber = "InputNumber"
+    SlugInput = "SlugInput"
+    EmailInput = "EmailInput"
+    PhoneInput = "PhoneInput"
+    UrlInput = "UrlInput"
     PasswordInput = "PasswordInput"
     TextArea = "TextArea"
     RichTextArea = "RichTextArea"
+    JsonTextArea = "JsonTextArea"
     Select = "Select"
     AsyncSelect = "AsyncSelect"
     AsyncTransfer = "AsyncTransfer"
